import CarouselContainer from "@re-flex/styled/Carousel";
import SliderInner from "@re-flex/styled/CarouselInner";
import SlideItem from "@re-flex/styled/CarouselItem";
import { css } from "@re-flex/styles";
import React, { memo, useCallback, useEffect, useMemo } from "react";
import Button from "../Button";
import useSwipeable from "./useSwipable";
let onSwipe;
let onSwipeEnd;
let index = 0;
const Carousel = ({ children, initialIndex = 0 }) => {
    const countChild = React.Children.count(children);
    const [ref, container] = useSwipeable({
        onSwipe,
        onSwipeEnd,
    });
    useEffect(() => {
        if (container)
            goTo(initialIndex);
    }, [container, initialIndex]);
    const setPosition = (target, translateX) => {
        if (target) {
            target.style.setProperty("--slide-translateX", translateX + "px");
        }
    };
    onSwipe = useCallback((element, swipeX, swipeY) => {
        if (element) {
            const cWidth = element.clientWidth / countChild;
            element.style.transitionDuration = "0ms";
            const translateX = Math.min(cWidth * -index - swipeX, 100);
            setPosition(element, translateX);
        }
    }, []);
    onSwipeEnd = (element, swipeX, swipeY) => {
        element.style.transitionDuration = "200ms";
        if (element) {
            const cWidth = element.clientWidth / countChild;
            if (Math.abs(swipeX) > 100) {
                let newIndex = index + (swipeX > 0 ? 1 : -1);
                newIndex =
                    newIndex >= countChild ? 0 : newIndex < 0 ? countChild - 1 : newIndex;
                index = newIndex;
                const translateX = Math.min(cWidth * -newIndex, 0);
                setPosition(element, translateX);
            }
            else {
                const translateX = Math.min(cWidth * -index, 0);
                setPosition(element, translateX);
            }
        }
    };
    const goTo = (defIndex) => {
        if (container) {
            index = defIndex % (countChild - 1);
            const cWidth = container.clientWidth / countChild;
            const translateX = Math.min(cWidth * -defIndex, 0);
            setPosition(container, translateX);
        }
    };
    const next = () => {
        const nextIndex = Math.min(index + 1, countChild - 1);
        index = nextIndex === countChild - 1 ? 0 : nextIndex;
        if (container) {
            const cWidth = container.clientWidth / countChild;
            const translateX = Math.min(cWidth * -index, 0);
            setPosition(container, translateX);
        }
    };
    const prev = () => {
        const prevIndex = Math.max(index - 1, 0);
        index = prevIndex || countChild - 1;
        if (container) {
            const cWidth = container.clientWidth / countChild;
            const translateX = Math.min(cWidth * -index, 0);
            setPosition(container, translateX);
        }
    };
    const slideList = useMemo(() => {
        return React.Children.map(children, (el, i) => (React.createElement(SlideItem, { key: i }, React.cloneElement(el, {
            ...el.props,
            draggable: false,
        }))));
    }, [container]);
    return (React.createElement(CarouselContainer, null,
        React.createElement(SliderInner, { ref: ref, className: css({ width: countChild + "00%" }) }, slideList),
        React.createElement("div", null,
            React.createElement(Button, { onClick: prev }, "Previous"),
            React.createElement(Button, { onClick: next }, "Next"))));
};
export default memo(Carousel);
