import clsx from "clsx";
import React, { useMemo } from "react";
import { useBlockLayout, useFilters, useGlobalFilter, useGroupBy, usePagination, useResizeColumns, useRowSelect, useSortBy, useTable, } from "react-table";
import Table from "../Table";
const ArrowIcon = ({ active = false, opacity = 0, }) => (React.createElement("svg", { style: {
        transition: "all .125s linear",
        transform: `rotate(${active ? 180 : 0}deg)`,
        opacity,
    }, stroke: "currentColor", fill: "none", strokeWidth: "2", viewBox: "0 0 24 24", strokeLinecap: "round", strokeLinejoin: "round", height: "1em", width: "1em", xmlns: "http://www.w3.org/2000/svg" },
    React.createElement("line", { x1: "12", y1: "5", x2: "12", y2: "19" }),
    React.createElement("polyline", { points: "19 12 12 19 5 12" })));
const DataTable = ({ columns, data, options: { headerEnable = true, footerEnable, sortingEnable = true, filterEnable, paginationEnable = true, rowSelctionEnable, groupingEnable, globalFilterEnable, resizeEnable = true, } = {}, }) => {
    const initialRules = useMemo(() => {
        const rules = [];
        if (sortingEnable)
            rules.push(useSortBy);
        if (filterEnable)
            rules.push(useFilters);
        if (globalFilterEnable)
            rules.push(useGlobalFilter);
        if (paginationEnable)
            rules.push(usePagination);
        if (rowSelctionEnable)
            rules.push(useRowSelect);
        if (groupingEnable)
            rules.push(useGroupBy);
        if (resizeEnable) {
            rules.push(useResizeColumns);
            rules.push(useBlockLayout);
        }
        return rules;
    }, [
        sortingEnable,
        filterEnable,
        paginationEnable,
        rowSelctionEnable,
        groupingEnable,
        globalFilterEnable,
        resizeEnable,
    ]);
    const { getTableProps, getTableBodyProps, headerGroups, rows, prepareRow, footerGroups, } = useTable({
        columns: columns,
        data: data,
    }, ...initialRules);
    return (React.createElement(Table, { ...getTableProps() },
        headerEnable === true && (React.createElement(Table.THead, null, headerGroups.map((headerGroup) => (React.createElement(Table.Tr, { ...headerGroup.getHeaderGroupProps() }, headerGroup.headers.map((column) => (React.createElement(Table.Th, { className: clsx({
                ["th-sorting"]: sortingEnable && column.getSortByToggleProps(),
            }), ...column.getHeaderProps(column.getSortByToggleProps()) },
            column.render("Header"),
            sortingEnable && (React.createElement(ArrowIcon, { active: column.isSortedDesc, opacity: column.isSorted ? 1 : 0 })),
            resizeEnable && (React.createElement("div", { ...column.getResizerProps(), className: `resizer ${column.isResizing ? "isResizing" : ""}` })))))))))),
        React.createElement(Table.TBody, { ...getTableBodyProps() }, rows.slice(0, 10).map((row, i) => {
            prepareRow(row);
            return (React.createElement(Table.Tr, { key: i, className: "table-body-row", ...row.getRowProps() }, row.cells.map((cell, k) => {
                const cellData = cell.render("Cell");
                return (React.createElement(Table.Td, { key: k, ...cell.getCellProps() }, cellData));
            })));
        })),
        footerEnable && (React.createElement(Table.TFoot, null, footerGroups.map((group, i) => (React.createElement("tr", { key: i, ...group.getFooterGroupProps() }, group.headers.map((column, k) => (React.createElement("td", { key: k, ...column.getFooterProps() }, column.render("Footer")))))))))));
};
export default DataTable;
