import dayjs from "dayjs";
import React, { createContext, useContext, useMemo } from "react";
import useSetState from "../hooks/useSetState";
import generateDateRows from "./Helpers/generatedRows";
const DatePickerContext = createContext({
    dateLists: {
        dayNames: [],
        weekList: { first: [], last: [] },
        monthList: [],
        yearList: [],
    },
    onChangeSelectedDate: (d) => null,
    controls: {
        prevWeek: (index) => null,
        nexvWeek: (index) => null,
        prevMonth: (index) => null,
        nextMonth: (index) => null,
        prevYear: (index) => null,
        nextYear: (index) => null,
    },
    setState: (f) => null,
    state: {
        today: dayjs(),
        previewDate: [dayjs()],
        dateMarks: new Map(),
        selectedDate: [],
        panelType: undefined,
        embed: false,
        type: "picker",
        mode: "default",
        onSelectDate: undefined,
        containerProps: { shadow: 2, p: 8, radius: 8 },
        Trigger: () => React.createElement(React.Fragment, null),
        locale: undefined,
    },
});
const fillMap = (size, callback) => {
    return Array(size).fill("").map(callback);
};
export const DatePickerProvider = ({ today = dayjs(), previewDate, dateMarks = new Map(), selectedDate = [], panelType = undefined, embed = false, type = "picker", mode = "default", onSelectDate = undefined, containerProps = {}, Trigger = () => null, locale = undefined, children, }) => {
    const [state, setState] = useSetState({
        today,
        previewDate: mode === "range" ? [today, today.add(1, "month")] : [today],
        dateMarks,
        selectedDate,
        panelType,
        embed,
        type,
        mode,
        onSelectDate,
        containerProps,
        Trigger,
        locale,
    });
    const changePreviewDate = (selectedTypeIndex, selectedType) => {
        setState({
            previewDate: mode === "range"
                ? [
                    dayjs(state.previewDate[0].set(selectedType, selectedTypeIndex)),
                    dayjs(state.previewDate[0]
                        .set(selectedType, selectedTypeIndex)
                        .add(1, "month")),
                ]
                : [dayjs(state.previewDate[0].set(selectedType, selectedTypeIndex))],
        });
    };
    const dateLists = useMemo(() => {
        const yearList = fillMap(150, (_, k) => 1970 + k);
        const dayNames = fillMap(7, (_, k) => dayjs().day(k).format("ddd"));
        const monthList = fillMap(12, (_, k) => dayjs().set("month", k)?.format("MMM"));
        const weekList = {
            first: generateDateRows(state.previewDate[0]),
            last: generateDateRows(state.previewDate[1] || dayjs()),
        };
        return { dayNames, monthList, weekList, yearList };
    }, [state.previewDate]);
    const controls = useMemo(() => {
        return {
            prevWeek: (index) => changePreviewDate(index, "day"),
            nexvWeek: (index) => changePreviewDate(index, "day"),
            prevMonth: (index) => changePreviewDate(state.previewDate[0].month() - 1, "month"),
            nextMonth: (index) => changePreviewDate(state.previewDate[0].month() + 1, "month"),
            prevYear: (index) => changePreviewDate(state.previewDate[0].year() - 1, "year"),
            nextYear: (index) => changePreviewDate(state.previewDate[0].year() + 1, "year"),
        };
    }, [state.previewDate]);
    const onChangeSelectedDate = (day) => {
        setState((beforeDates) => {
            let selectedDates = beforeDates.selectedDate;
            if (mode === "range") {
                if (selectedDates.length === 1) {
                    selectedDates[1] = day;
                }
                else if (selectedDates.length === 2) {
                    selectedDates = [day];
                }
                else {
                    selectedDates = [...selectedDates, day];
                }
            }
            else {
                selectedDates = [day];
            }
            return { ...beforeDates, selectedDate: selectedDates };
        });
    };
    return (React.createElement(DatePickerContext.Provider, { value: {
            state,
            controls,
            dateLists,
            setState,
            onChangeSelectedDate,
        } }, children));
};
export const useDatePicker = () => {
    const docPicker = useContext(DatePickerContext);
    return docPicker;
};
