import { css } from "@re-flex/styles";
import { convertUnit2Rem } from "@re-flex/utils";
import React, { Fragment, useRef, useState } from "react";
import Box from "../Box";
import IconButton from "../IconButton";
import Popper from "../Popper";
import { SysIconsChevronLeft, SysIconsChevronRight, SysIconsFirstPage, SysIconsLastPage, } from "../SystemIcons";
import Table from "../Table";
import Text from "../Typography";
import WeekContents from "./Content/Weeks";
import { DatePickerProvider, useDatePicker } from "./Context";
import WeekDayHeader from "./Headers/WeekDays";
const DatePickerBase = ({}) => {
    const { state: { containerProps, previewDate, mode }, controls, } = useDatePicker();
    return (React.createElement(Box, { boxShadow: mode === "range" ? 0 : 2, p: mode === "range" ? 0 : 0.5, borderRadius: mode === "range" ? 0 : 1, ...containerProps },
        React.createElement(Box, { sx: {
                display: "flex",
                alignItems: "center",
                padding: "12px",
            } },
            React.createElement(IconButton, { onClick: () => controls.prevYear(-1), size: 1.5 },
                React.createElement(SysIconsFirstPage, null)),
            React.createElement(IconButton, { onClick: () => controls.nextYear(1), size: 1.5 },
                React.createElement(SysIconsLastPage, null)),
            React.createElement("div", { className: css({ flexGrow: 1 }) }),
            React.createElement(Text, { align: "center" },
                mode === "range" && (React.createElement(Text, { size: 12 }, previewDate[0].format("YYYY"))),
                mode === "range"
                    ? previewDate[0].format("MMM") +
                        " - " +
                        previewDate[1].format("MMM")
                    : previewDate[0].format("MMM, YYYY")),
            React.createElement("div", { className: css({ flexGrow: 1 }) }),
            React.createElement(IconButton, { onClick: () => controls.prevMonth(-1), size: 1 },
                React.createElement(SysIconsChevronLeft, null)),
            React.createElement(IconButton, { onClick: () => controls.nextMonth(1), size: 1 },
                React.createElement(SysIconsChevronRight, null))),
        React.createElement("div", { className: css({ display: "inline-flex" }) },
            React.createElement(Table, { className: css({
                    minWidth: "auto",
                    "th,td": { padding: "6px" },
                }) },
                React.createElement(WeekDayHeader, null),
                React.createElement(WeekContents, { role: "first" })),
            mode === "range" && (React.createElement(Fragment, null,
                React.createElement("div", { className: css({
                        borderLeft: "2px solid #9993",
                        marginLeft: convertUnit2Rem(12),
                        paddingLeft: convertUnit2Rem(12),
                    }) }),
                React.createElement(Table, { className: css({
                        minWidth: "auto",
                        "th,td": { padding: convertUnit2Rem(6) },
                    }) },
                    React.createElement(WeekDayHeader, null),
                    React.createElement(WeekContents, { role: "last" })))))));
};
const DatePickerRange = () => {
    const popperRef = useRef();
    const [attachTo, setAttachTo] = useState(undefined);
    const { state: { Trigger, containerProps, previewDate }, } = useDatePicker();
    return (React.createElement(Fragment, null,
        React.createElement(Trigger, { onClick: (e) => {
                if (!attachTo)
                    setAttachTo(e.target);
                setTimeout(() => {
                    popperRef?.current?.open();
                }, 15);
            } }),
        React.createElement(Popper, { attachTo: attachTo, placement: "bottom", popperRef: popperRef, content: React.createElement(Box, { width: "auto", className: css({ display: "flex" }), ...containerProps },
                React.createElement(DatePickerBase, null)) })));
};
const DatePickerWrapper = ({ ...props }) => (React.createElement(DatePickerProvider, { ...props },
    React.createElement(DatePickerRange, null)));
export default DatePickerWrapper;
