import { styled } from "@re-flex/styles";
import { fastMemoize } from "@re-flex/utils";
import React from "react";
const frGetter = fastMemoize((value) => typeof value === "number" ? `repeat(${value}, 1fr)` : value);
const isDefined = (e) => e !== undefined;
const formatAreas = (areas) => areas.join(" ");
const RowGenerate = styled("div")(({ display = "grid", columns = 12, gap, columnGap, rowGap, height = "auto", minRowHeight = "20px", flow, rows, areas, justifyContent, alignContent, }) => {
    return [
        { display },
        { height: height },
        isDefined(flow) && { gridAutoFlow: flow },
        { gridAutoRows: `minmax(${minRowHeight}, auto)` },
        isDefined(rows) && { gridTemplateRows: frGetter(rows) },
        isDefined(columns) && { gridTemplateColumns: frGetter(columns) },
        isDefined(areas) && {
            gridTemplateAreas: typeof areas === "string" ? areas : formatAreas(areas),
        },
        isDefined(gap) && { gridGap: gap },
        isDefined(columnGap) && { columnGap: columnGap },
        isDefined(rowGap) && { rowGap: rowGap },
        isDefined(justifyContent) && { justifyContent: justifyContent },
        isDefined(alignContent) && { alignContent: alignContent },
    ];
});
const ColGenerate = styled("div")(({ xs, sm, md, lg, xl, width = 1, height = 1, top, left, middle, align = "left", area, }) => {
    let obj = [
        isDefined(width) && { gridColumnEnd: `span ${width}` },
        isDefined(height) && { gridRowEnd: `span ${height}` },
        isDefined(left) && { gridColumnStart: left },
        isDefined(top) && { gridRowStart: top },
        isDefined(align) && { textAlign: align },
        isDefined(area) && { gridArea: area },
        middle && {
            display: "inline-flex",
            flexFlow: "column wrap",
            justifyContent: "center",
            justifySelf: "stretch",
        },
        isDefined(xs) && {
            xs: { gridColumnEnd: `span ${xs}` },
        },
        isDefined(sm) && {
            sm: { gridColumnEnd: `span ${sm}` },
        },
        isDefined(md) && {
            md: { gridColumnEnd: `span ${md}` },
        },
        isDefined(lg) && {
            lg: { gridColumnEnd: `span ${lg}` },
        },
        isDefined(xl) && {
            xl: { gridColumnEnd: `span ${xl}` },
        },
    ];
    return obj;
});
const Grid = ({ children, ...rest }) => {
    return React.createElement(RowGenerate, { ...rest }, children);
};
export const Col = ({ children, ...rest }) => {
    return React.createElement(ColGenerate, { ...rest }, children);
};
Grid.Col = Col;
export default Grid;
