import React from "react";
const useOutsideClickListener = ({ onClickAway, mouseEvent = "click", touchEvent = "touchend", }) => {
    let [element, ref] = React.useState(null);
    React.useEffect(() => {
        if (!element) {
            return;
        }
        const handleEvents = (event) => {
            if (element && element.contains(event.target)) {
                return;
            }
            onClickAway(event);
        };
        document.addEventListener(mouseEvent, handleEvents);
        document.addEventListener(touchEvent, handleEvents);
        return () => {
            document.removeEventListener(mouseEvent, handleEvents);
            document.removeEventListener(touchEvent, handleEvents);
        };
    }, [mouseEvent, onClickAway, touchEvent, element]);
    return ref;
};
const OutsideClickListener = ({ onClickAway, mouseEvent = "click", touchEvent = "touchend", children, ...props }) => {
    const node = useOutsideClickListener({
        onClickAway,
        mouseEvent,
        touchEvent,
    });
    return (React.createElement(React.Fragment, null, React.cloneElement(children, { ...props, ref: node })));
};
export default OutsideClickListener;
