import StyledRipple from "@re-flex/styled/Ripple";
import { useTheme } from "@re-flex/styles";
import clsx from "clsx";
import React, { useCallback, useEffect, useState, } from "react";
const Ripple = ({ duration, color, enableHover, center }) => {
    const theme = useTheme();
    const [ripples, setRipples] = useState([]);
    let startTimeout = null;
    color = color || "currentcolor";
    duration = duration || theme.transitions.duration.enteringScreen * 1.5;
    useEffect(() => {
        return () => {
            setRipples(Array.from([]));
            if (startTimeout !== null) {
                clearTimeout(startTimeout);
            }
        };
    }, []);
    const onRipple = useCallback((event) => {
        const attach = event.currentTarget;
        if (!attach) {
            return;
        }
        event.persist();
        const rect = attach.getBoundingClientRect();
        const { left, top } = rect;
        let rippleX = attach.clientLeft - left;
        let rippleY = attach.clientTop - top;
        let rippleSize = 0;
        if (center) {
            rippleX = Math.round(rect.width / 2);
            rippleY = Math.round(rect.height / 2);
            rippleSize = Math.sqrt((2 * Math.pow(rect.width, 2) + Math.pow(rect.height, 2)) / 3);
        }
        else {
            let clientX = 0;
            let clientY = 0;
            if (Array.isArray(event?.touches)) {
                clientX = event.touches.at(-1).clientX;
                clientY = event.touches.at(-1).clientY;
            }
            else {
                clientX = event.clientX;
                clientY = event.clientY;
            }
            rippleX = Math.round(clientX - rect.left);
            rippleY = Math.round(clientY - rect.top);
            const sizeX = Math.max(Math.abs(attach.clientWidth - rippleX), rippleX) * 2 + 2;
            const sizeY = Math.max(Math.abs(attach.clientHeight - rippleY), rippleY) * 2 + 2;
            rippleSize = Math.sqrt(sizeX ** 2 + sizeY ** 2);
        }
        const rippleId = `ripple${Number(Date.now()).toString(32)}`;
        const defaultNewRippleItem = {
            id: rippleId,
            style: {
                "--ripple-width": `${rippleSize}px`,
                "--ripple-height": `${rippleSize}px`,
            },
        };
        setRipples((f) => [
            ...f,
            center
                ? defaultNewRippleItem
                : {
                    id: rippleId,
                    style: {
                        ...defaultNewRippleItem.style,
                        "--ripple-left": `${rippleX - rippleSize / 2}px`,
                        "--ripple-top": `${rippleY - rippleSize / 2}px`,
                    },
                },
        ]);
    }, [center]);
    const stop = useCallback((e) => {
        e.persist();
        if (startTimeout !== null) {
            clearTimeout(startTimeout);
        }
        if (ripples.length) {
            startTimeout = setTimeout(() => {
                setRipples((r) => r.slice(1));
            }, duration * 1.01);
        }
    }, []);
    const handleMouseDown = useCallback((e) => {
        onRipple(e);
    }, [onRipple]);
    const handleMouseUp = useCallback((e) => {
        stop(e);
    }, [stop]);
    const handleMouseLeave = useCallback((e) => {
        stop(e);
    }, [stop]);
    const handleTouchStart = useCallback((e) => {
        onRipple(e);
    }, [onRipple]);
    const handleTouchEnd = useCallback((e) => {
        stop(e);
    }, [stop]);
    const handleTouchMove = useCallback((e) => {
        stop(e);
    }, [stop]);
    return (React.createElement(StyledRipple, { rippleColor: color, rippleDuration: duration, enableHover: enableHover, className: clsx(`${theme.prefix}-ripple-container`, {
            "ripple-center": center,
        }), onMouseDown: handleMouseDown, onMouseUp: handleMouseUp, onMouseLeave: handleMouseLeave, onTouchStart: handleTouchStart, onTouchEnd: handleTouchEnd, onTouchMove: handleTouchMove }, ripples.map(({ id, style }, rippleIndex) => (React.createElement("span", { key: id, id: id, style: style, className: `${theme.prefix}-ripples`, onAnimationEnd: () => {
            setRipples((r) => (r.length === 1 ? [] : r.slice(rippleIndex)));
        } })))));
};
export default Ripple;
